
# Slot: has_member


the values of the slot is multivalued with at least one member satisfying the condition

URI: [linkml:has_member](https://w3id.org/linkml/has_member)


## Domain and Range

None &#8594;  <sub>0..1</sub> anonymous_slot_expression

## Parents

 *  is_a: list_value_specification_constant

## Children


## Used by

 * anonymous_slot_expression
 * slot_definition
 * slot_expression
